@@ -1,4 +1,4 @@
-#' Is an XML opening tag with value 'section' present amongst the lines of
+#' Is an XML opening tag with value 'section' present among the lines of
 #'   the text?
 #' @param lines lines of an XML text
 #' @param section if NA, this function returns TRUE if there is any
@@ -6,7 +6,7 @@
 #'   this function returns TRUE if that tag matches \code{section}
 #' @return lines of XML text
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 has_xml_opening_tag <- function(
   lines,
   section = NA
@@ -17,8 +17,10 @@ has_xml_opening_tag <- function(
     stop("'section' must be NA or a word")
   }
   if (beautier::is_one_na(section)) {
-    tag <- get_xml_opening_tag(lines) # nolint
+    tag <- beautier::get_xml_opening_tag(lines)
     return(!beautier::is_one_na(tag))
   }
-  !beautier::is_one_na(find_first_xml_opening_tag_line(lines, section))
+  !beautier::is_one_na(
+    beautier::find_first_xml_opening_tag_line(lines, section)
+  )
 }
