@@ -4,7 +4,7 @@
 #' @param param_id the first parameter's ID
 #' @return a list of initialized clock models
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 init_clock_models <- function(
   fasta_filenames,
   clock_models,
@@ -14,7 +14,7 @@ init_clock_models <- function(
   testit::assert(all(file.exists(fasta_filenames)))
   testit::assert(beautier::are_clock_models(clock_models))
   testit::assert(length(clock_models) == length(fasta_filenames))
-  ids <- get_alignment_ids_from_fasta_filenames(fasta_filenames) # nolint beautier function
+  ids <- beautier::get_alignment_ids_from_fasta_filenames(fasta_filenames)
   n_taxa <- beautier::get_n_taxa(fasta_filenames[1])
 
   for (i in seq_along(clock_models)) {
@@ -24,9 +24,9 @@ init_clock_models <- function(
     if (beautier::is_rln_clock_model(clock_model)) {
       # RLN
 
-      if (!is_init_rln_clock_model(clock_model)) { # nolint beautier function
+      if (!beautier::is_init_rln_clock_model(clock_model)) {
 
-        clock_model <- init_rln_clock_model( # nolint beautier function call
+        clock_model <- beautier::init_rln_clock_model(
           clock_model,
           distr_id = distr_id,
           param_id = param_id
@@ -44,9 +44,9 @@ init_clock_models <- function(
     } else {
       testit::assert(beautier::is_strict_clock_model(clock_model))
 
-      if (!is_init_strict_clock_model(clock_model)) { # nolint beautier function
+      if (!beautier::is_init_strict_clock_model(clock_model)) {
 
-        clock_model <- init_strict_clock_model( # nolint beautier function call
+        clock_model <- beautier::init_strict_clock_model(
           clock_model,
           distr_id = distr_id,
           param_id = param_id
@@ -70,20 +70,32 @@ init_clock_models <- function(
 #' @inheritParams default_params_doc
 #' @return an initialized Relaxed Log-Normal clock model
 #' @author Richèl J.C. Bilderbeek
+#' @examples
+#' library(testthat)
+#'
+#' rln_clock_model <- create_rln_clock_model()
+#' expect_false(is_init_rln_clock_model(rln_clock_model))
+#' rln_clock_model <- init_rln_clock_model(rln_clock_model)
+#' # Dimension is set to NA by default, for unknown reasons.
+#' # Because 'init_rln_clock_model' does not initialize it (for
+#' # unknown reasons), set it manually
+#' rln_clock_model$dimension <- 42
+#' expect_true(is_init_rln_clock_model(rln_clock_model))
+#' @export
 init_rln_clock_model <- function(
   rln_clock_model,
-  distr_id,
-  param_id
+  distr_id = 0,
+  param_id = 0
 ) {
   testit::assert(beautier::is_rln_clock_model(rln_clock_model))
-  ucldstdev_distr <- init_distr( # nolint beautier function
+  ucldstdev_distr <- beautier::init_distr(
     rln_clock_model$ucldstdev_distr,
     distr_id,
     param_id
   )
   distr_id <- distr_id + 1
   param_id <- param_id + beautier::get_distr_n_params(ucldstdev_distr)
-  mean_rate_prior_distr <- init_distr( # nolint beautier function
+  mean_rate_prior_distr <- beautier::init_distr(
     rln_clock_model$mean_rate_prior_distr,
     distr_id,
     param_id
@@ -116,16 +128,22 @@ init_rln_clock_model <- function(
 #' @return an initialized strict clock model
 #' @author Richèl J.C. Bilderbeek
 #' @examples
-#'   strict_clock_model <- create_strict_clock_model()
+#' library(testthat)
+#'
+#' strict_clock_model <- create_strict_clock_model()
+#' expect_false(is_init_strict_clock_model(strict_clock_model))
+#' strict_clock_model <- init_strict_clock_model(strict_clock_model)
+#' expect_true(is_init_strict_clock_model(strict_clock_model))
+#' @export
 init_strict_clock_model <- function(
   strict_clock_model,
-  distr_id,
-  param_id
+  distr_id = 0,
+  param_id = 0
 ) {
   testit::assert(beautier::is_strict_clock_model(strict_clock_model))
 
   # clock_rate_distr
-  strict_clock_model$clock_rate_distr <- init_distr( # nolint beautier function
+  strict_clock_model$clock_rate_distr <- beautier::init_distr(
     strict_clock_model$clock_rate_distr,
     distr_id,
     param_id
