@@ -8,12 +8,14 @@
 #'   and \code{\link{create_tn93_site_model}}
 #' @author Richèl J.C. Bilderbeek
 #' @examples
-#'   testit::assert(beautier:::is_freq_equilibrium_name("estimated"))
-#'   testit::assert(beautier:::is_freq_equilibrium_name("empirical"))
-#'   testit::assert(beautier:::is_freq_equilibrium_name("all_equal"))
-#' @noRd
+#' library(testthat)
+#'
+#' expect_true(is_freq_equilibrium_name("estimated"))
+#' expect_true(is_freq_equilibrium_name("empirical"))
+#' expect_true(is_freq_equilibrium_name("all_equal"))
+#' @export
 is_freq_equilibrium_name <- function(
   name
 ) {
-  name %in% get_freq_equilibrium_names() # nolint beautier function
+  name %in% beautier::get_freq_equilibrium_names()
 }
