@@ -4,12 +4,12 @@
 #'   initialized gamma site_models object
 #' @return TRUE if x is an initialized gamma site model
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 is_init_gamma_site_model <- function(
   x
 ) {
-  if (!is_gamma_site_model(x)) return(FALSE) # nolint beautier function
-  if (is_one_na(x$gamma_shape_prior_distr)) return(TRUE) # nolint beautier function
-  if (!is_init_distr(x$gamma_shape_prior_distr)) return(FALSE) # nolint beautier function
+  if (!beautier::is_gamma_site_model(x)) return(FALSE)
+  if (beautier::is_one_na(x$gamma_shape_prior_distr)) return(TRUE)
+  if (!beautier::is_init_distr(x$gamma_shape_prior_distr)) return(FALSE)
   TRUE
 }
